@@ -29,7 +29,7 @@
 #include "lib/bostree.h"
 
 #ifndef PQIV_VERSION
-#define PQIV_VERSION "2.10.4"
+#define PQIV_VERSION "2.11"
 #endif
 
 #define FILE_FLAGS_ANIMATION      (guint)(1)
@@ -284,6 +284,7 @@ typedef enum {
 	ACTION_MONTAGE_MODE_RETURN_CANCEL,
 	ACTION_MOVE_WINDOW,
 	ACTION_TOGGLE_BACKGROUND_PATTERN,
+	ACTION_TOGGLE_NEGATE_MODE,
 } pqiv_action_t;
 
 typedef union {
